==> haskell-hspec-hedgehog-0.0.1.2-256-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-3v8gUeQCPNUKCYqSxM18pD
key:                  hspec-hedgehog-0.0.1.2-3v8gUeQCPNUKCYqSxM18pD
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  4f8aa6ee2a940a0337fe4bfd3aa1f4a1
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-3v8gUeQCPNUKCYqSxM18pD
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    hedgehog-1.2-6PcYeqnRpof27D7X8ClW1m
    hspec-2.10.9-BvZCMC9GHSl5PUeqGmyPC0
    hspec-core-2.10.9-6Oo46zOT12G3ZYTFJbCUOO
    splitmix-0.1.0.5-4IFL1NtOdKh2TjOwEHJjMs

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-hedgehog-0.0.1.2-260-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-JsnQUHDBL6WHqi2Pa41afL
key:                  hspec-hedgehog-0.0.1.2-JsnQUHDBL6WHqi2Pa41afL
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  8641e19ca7be50e42a64def6178b3af7
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-JsnQUHDBL6WHqi2Pa41afL
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    hedgehog-1.2-45sXUMtiCZS9ksRmbj0vBk
    hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
    hspec-core-2.10.9-EPbsf4CX1VNHe1gcsgpM0I
    splitmix-0.1.0.5-HVESxjxwSfmC4HE369voNE

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
